!include "Sections.nsh"

; The name of the installer
Name "Malx media player"
SetCompressor LZMA

!define /date BUILDDATE "%Y%m%d"

!IFDEF WIN64
!define ARCHTAG "-win64"
!ELSE
!define ARCHTAG "-win32"
!ENDIF

!IFDEF SHIPPDB
!define DEBUGTAG "-debug"
!ELSE
!define DEBUGTAG ""
!ENDIF

!IFDEF UNICODE
!define UNICODETAG "-unicode"
!ELSE
!define UNICODETAG ""
!ENDIF

; The file to write
OutFile "mplay${ARCHTAG}-installer${UNICODETAG}${DEBUGTAG}-${BUILDDATE}.exe"

; The default installation directory
InstallDir $PROGRAMFILES\Mplay

; Registry key to check for directory (so if you install again, it will 
; overwrite the old one automatically)
InstallDirRegKey HKLM "Software\Malx media player" "Install_Dir"

;--------------------------------

; Pages

Page license
Page directory
Page instfiles

UninstPage uninstConfirm
UninstPage instfiles

LicenseText "This software is licensed under the GPL, which attaches some conditions to modification and distribution (but not to use.)  Please read the full text for these conditions."
LicenseData "COPYING"

;--------------------------------

; The stuff to install
Section "Mplay (required)"

  SectionIn RO
  
  ; Set output path to the installation directory.
  SetOutPath $INSTDIR
  
  ; Put file there
  File "src\mplay.exe"
!IFDEF SHIPPDB
  File "src\mplay.pdb"
!ENDIF
  
  ; Write the installation path into the registry
  WriteRegStr HKLM "SOFTWARE\Malx media player" "Install_Dir" "$INSTDIR"
  ; Write the uninstall keys for Windows
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\Mplay" "DisplayName" "Malx Media Player"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\Mplay" "UninstallString" '"$INSTDIR\uninstall.exe"'
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\Mplay" "NoModify" 1
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\Mplay" "NoRepair" 1
  WriteUninstaller "uninstall.exe"

  CreateDirectory "$SMPROGRAMS\Malx Media Player"
  CreateShortCut "$SMPROGRAMS\Malx Media Player\Malx Media Player.lnk" "$INSTDIR\mplay.exe" "" "$INSTDIR\mplay.exe" 0

SectionEnd

;--------------------------------

; Uninstaller

Section "Uninstall"

  ; Remove registry keys
  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\Mplay"
  DeleteRegKey HKLM SOFTWARE\Mplay

  ; Remove files and uninstaller
  Delete $INSTDIR\mplay.exe
!IFDEF SHIPPDB
  Delete $INSTDIR\mplay.pdb
!ENDIF
  Delete $INSTDIR\uninstall.exe

  ; Remove shortcuts, if any
  Delete "$SMPROGRAMS\Malx Media Player\*.*"

  ; Remove directories used
  RMDir "$SMPROGRAMS\Malx Media Player"
  RMDir "$INSTDIR"

SectionEnd

